@@ -36,6 +36,7 @@
 
 #define d(x)
 
+static void pass_parent (GNCSearchCoreType *fe, gpointer parent);
 static void editable_enters (GNCSearchCoreType *fe);
 static void grab_focus (GNCSearchCoreType *fe);
 static GNCSearchCoreType *gncs_clone(GNCSearchCoreType *fe);
@@ -54,6 +55,7 @@ struct _GNCSearchInt64Private
 {
     GtkWidget *entry;
     GNCAmountEdit *gae;
+    GtkWindow *parent;
 };
 
 #define _PRIVATE(o) \
@@ -101,6 +103,7 @@ gnc_search_int64_class_init (GNCSearchInt64Class *klass)
     object_class->finalize = gnc_search_int64_finalize;
 
     /* override methods */
+    gnc_search_core_type->pass_parent = pass_parent;
     gnc_search_core_type->editable_enters = editable_enters;
     gnc_search_core_type->grab_focus = grab_focus;
     gnc_search_core_type->validate = gncs_validate;
@@ -157,6 +160,19 @@ gnc_search_int64_set_how (GNCSearchInt64 *fi, QofQueryCompare how)
     fi->how = how;
 }
 
+static void
+pass_parent (GNCSearchCoreType *fe, gpointer parent)
+{
+    GNCSearchInt64 *fi = (GNCSearchInt64 *)fe;
+    GNCSearchInt64Private *priv;
+
+    g_return_if_fail (fi);
+    g_return_if_fail (IS_GNCSEARCH_INT64 (fi));
+
+    priv = _PRIVATE(fi);
+    priv->parent = GTK_WINDOW(parent);
+}
+
 static gboolean
 gncs_validate (GNCSearchCoreType *fe)
 {
