@@ -1024,7 +1024,7 @@ gnc_plugin_page_create_action_group (GncPluginPage *page, const gchar *group_nam
 
     priv = GNC_PLUGIN_PAGE_GET_PRIVATE(page);
     group = gtk_action_group_new(group_name);
-    gnc_gtk_action_group_set_translation_domain(group, GETTEXT_PACKAGE);
+    gtk_action_group_set_translation_domain(group, GETTEXT_PACKAGE);
     priv->action_group = group;
     return group;
 }
