@@ -358,6 +358,13 @@ gnc_split_reg_init( GNCSplitReg *gsr )
     gsr->read_only = FALSE;
 }
 
+static void
+gnc_split_reg_pref_acc_labels (gpointer prefs, gchar *pref, gpointer user_data)
+{
+    GNCSplitReg *gsr = user_data;
+    gnucash_register_refresh_from_prefs (gsr->reg);
+}
+
 static void
 gnc_split_reg_init2( GNCSplitReg *gsr )
 {
@@ -369,6 +376,11 @@ gnc_split_reg_init2( GNCSplitReg *gsr )
     /* ordering is important here... setup_status before create_table */
     gsr_create_table( gsr );
     gsr_setup_table( gsr );
+
+    gnc_prefs_register_cb (GNC_PREFS_GROUP_GENERAL,
+                           GNC_PREF_ACCOUNTING_LABELS,
+                           gnc_split_reg_pref_acc_labels,
+                           gsr);
 }
 
 static
@@ -451,6 +463,11 @@ gnc_split_reg_dispose(GObject *obj)
         g_free (gsr->filter_text);
     gsr->filter_text = NULL;
 
+    gnc_prefs_remove_cb_by_func (GNC_PREFS_GROUP_GENERAL,
+                                 GNC_PREF_ACCOUNTING_LABELS,
+                                 gnc_split_reg_pref_acc_labels,
+                                 gsr);
+
     if (gsr->reg)
     {
         g_signal_handlers_disconnect_by_data (gsr->reg, gsr);
@@ -1288,6 +1305,10 @@ gsr_default_delete_handler( GNCSplitReg *gsr, gpointer data )
     trans = xaccSplitGetParent(split);
     cursor_class = gnc_split_register_get_current_cursor_class (reg);
 
+    /* test for blank_split reference pointing to split */
+    if (gnc_split_register_is_blank_split (reg, split))
+        gnc_split_register_change_blank_split_ref (reg, split);
+
     /* Deleting the blank split just cancels */
     {
         Split *blank_split = gnc_split_register_get_blank_split (reg);
@@ -2285,7 +2306,6 @@ static
 void
 gnc_split_reg_determine_read_only( GNCSplitReg *gsr )
 {
-    dialog_args *args = g_malloc(sizeof(dialog_args));
     SplitRegister *reg;
 
     if (qof_book_is_readonly(gnc_get_current_book()))
@@ -2297,7 +2317,8 @@ gnc_split_reg_determine_read_only( GNCSplitReg *gsr )
 
     if ( !gsr->read_only )
     {
-
+        dialog_args *args;
+        char *string = NULL;
         switch (gnc_split_reg_get_placeholder(gsr))
         {
         case PLACEHOLDER_NONE:
@@ -2305,14 +2326,14 @@ gnc_split_reg_determine_read_only( GNCSplitReg *gsr )
             return;
 
         case PLACEHOLDER_THIS:
-            args->string = _("This account may not be edited. If you want "
+            string = _("This account may not be edited. If you want "
                              "to edit transactions in this register, please "
                              "open the account options and turn off the "
                              "placeholder checkbox.");
             break;
 
         default:
-            args->string = _("One of the sub-accounts selected may not be "
+            string = _("One of the sub-accounts selected may not be "
                              "edited. If you want to edit transactions in "
                              "this register, please open the sub-account "
                              "options and turn off the placeholder checkbox. "
@@ -2322,6 +2343,8 @@ gnc_split_reg_determine_read_only( GNCSplitReg *gsr )
         }
         gsr->read_only = TRUE;
         /* Put up a warning dialog */
+        args = g_malloc(sizeof(dialog_args));
+        args->string = string;
         args->gsr = gsr;
         g_timeout_add (250, gtk_callback_bug_workaround, args); /* 0.25 seconds */
     }
