@@ -148,10 +148,10 @@ add_reconcile_date (gchar *so_far, Split *split, CsvExportInfo *info)
 
     if (xaccSplitGetReconcile (split) == YREC)
     {
-        Timespec     ts = {0,0};
-        const gchar *str_rec_date;
-        xaccSplitGetDateReconciledTS (split, &ts);
-        str_rec_date = gnc_print_date (ts);
+        time64 t = xaccSplitGetDateReconciled (split);
+        char str_rec_date[MAX_DATE_LENGTH + 1];
+        memset (str_rec_date, 0, sizeof(str_rec_date));
+        qof_print_date_buff (str_rec_date, sizeof(str_rec_date), t);
         result = g_strconcat (so_far, str_rec_date, info->mid_sep, NULL);
     }
     else
