@@ -266,11 +266,6 @@ for styling the invoice. Please see the exported report for the CSS class names.
   (gnc:register-inv-option (gnc:make-internal-option "Display" "My Company" #f))
   (gnc:register-inv-option (gnc:make-internal-option "Display" "My Company ID" #f))
 
-  (gnc:register-inv-option
-   (gnc:make-simple-boolean-option
-    (N_ "Display") (N_ "Title")
-    "a" (N_ "Display invoice title and invoice ID?") #t))
-
   (gnc:register-inv-option
    (gnc:make-simple-boolean-option
     (N_ "Display") (N_ "Due Date")
@@ -316,8 +311,8 @@ for styling the invoice. Please see the exported report for the CSS class names.
 
   (gnc:register-inv-option
    (gnc:make-simple-boolean-option
-    (N_ "Display") (N_ "Individual Taxes")
-    "o" (N_ "Display all the individual taxes?") #f))
+    (N_ "Display") (N_ "Use Detailed Tax Summary")
+    "o" (N_ "Display all tax categories separately (one per line) instead of one single tax line.?") #f))
 
   (gnc:register-inv-option (gnc:make-internal-option "Display" "Totals" #t))
 
@@ -415,7 +410,7 @@ for styling the invoice. Please see the exported report for the CSS class names.
      (gnc:lookup-option options section name)))
 
   (let ((show-payments (opt-val "Display" "Payments"))
-        (display-all-taxes (opt-val "Display" "Individual Taxes"))
+        (display-all-taxes (opt-val "Display" "Use Detailed Tax Summary"))
         (display-subtotal? (opt-val "Display" "Subtotal"))
         (lot (gncInvoiceGetPostedLot invoice))
         (txn (gncInvoiceGetPostedTxn invoice))
@@ -675,7 +670,8 @@ for styling the invoice. Please see the exported report for the CSS class names.
 (define (make-img img-url)
   ;; just an image
   (gnc:make-html-text
-   (gnc:html-markup-img img-url)))
+   (gnc:html-markup-img
+    (make-file-url img-url))))
 
 (define (make-client-table owner orders options)
   (define (opt-val section name)
@@ -801,6 +797,9 @@ for styling the invoice. Please see the exported report for the CSS class names.
                                 (else
                                  (_ "Invoice"))))
                (title (if (string-null? custom-title) default-title custom-title))
+               ;; Translators: This is the format of the invoice title.
+               ;; The first ~a is "Invoice", "Credit Note"... and the second the number.
+               ;; Replace " #" by whatever is common as number abbreviation, i.e. "~a Nr. ~a"
                (invoice-title (format #f (_"~a #~a") title (gncInvoiceGetID invoice)))
                (layout-lookup-table (list (cons 'none #f)
                                           (cons 'picture (gnc:make-html-div/markup
@@ -822,17 +821,14 @@ for styling the invoice. Please see the exported report for the CSS class names.
                                                         (qof-print-date (current-time))))))
                (layout-lookup (lambda (loc) (cdr (assq (opt-val "Layout" loc) layout-lookup-table)))))
 
-          (gnc:html-document-set-title! document invoice-title)
-
           (gnc:html-document-set-style-text! document (opt-val "Layout" "CSS"))
 
           (let ((main-table (gnc:make-html-table)))
 
-            (if (opt-val "Display" "Title")
-                (gnc:html-table-append-row! main-table
-                                            (gnc:make-html-table-cell/size
-                                             1 2 (gnc:make-html-div/markup
-                                                  "invoice-title" invoice-title))))
+            (gnc:html-table-append-row! main-table
+                                        (gnc:make-html-table-cell/size
+                                         1 2 (gnc:make-html-div/markup
+                                              "invoice-title" invoice-title)))
 
             (gnc:html-table-append-row! main-table
                                         (list (layout-lookup "Row 1 Left")
