@@ -201,7 +201,7 @@
          (lambda (disp-col-name)
            (set-option! options "Display" disp-col-name setting))
          '("My Company" "My Company ID" "Due Date"
-           "Individual Taxes" "Totals" "Subtotal" "References"
+           "Use Detailed Tax Summary" "Totals" "Subtotal" "References"
            "Billing Terms" "Billing ID" "Invoice Notes"
            "Payments" "Job Details"))
         options))
