@@ -23,6 +23,17 @@
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;; Functions to get splits with interesting data from accounts.
 
+;; helper function. queries book for all splits in accounts before
+;; end-date (end-date can be #f)
+(define (get-all-splits accounts end-date)
+  (let ((query (qof-query-create-for-splits)))
+    (qof-query-set-book query (gnc-get-current-book))
+    (gnc:query-set-match-non-voids-only! query (gnc-get-current-book))
+    (xaccQueryAddAccountMatch query accounts QOF-GUID-MATCH-ANY QOF-QUERY-AND)
+    (xaccQueryAddDateMatchTT query #f 0 (and end-date #t) (or end-date 0) QOF-QUERY-AND)
+    (let ((splits (qof-query-run query)))
+      (qof-query-destroy query)
+      splits)))
 
 ;; Returns a list of all splits in the 'currency-accounts' up to
 ;; 'end-date' which have two different commodities involved, one of
@@ -30,42 +41,15 @@
 ;; 'commodity' != #f ).
 (define (gnc:get-match-commodity-splits
          currency-accounts end-date commodity)
-  (let ((query (qof-query-create-for-splits))
-        (splits #f))
-
-    (qof-query-set-book query (gnc-get-current-book))
-    (gnc:query-set-match-non-voids-only! query (gnc-get-current-book))
-    (xaccQueryAddAccountMatch query
-                              currency-accounts
-                              QOF-GUID-MATCH-ANY QOF-QUERY-AND)
-    (if end-date
-        (xaccQueryAddDateMatchTT
-         query #f end-date #t end-date QOF-QUERY-AND))
-
-    ;; Get the query result, i.e. all splits in currency
-    ;; accounts.
-    (set! splits (filter
-                  ;; Filter such that we get only those splits
-                  ;; which have two *different* commodities
-                  ;; involved.
-                  (lambda (s) (let ((trans-comm
-                                     (xaccTransGetCurrency
-                                      (xaccSplitGetParent s)))
-                                    (acc-comm
-                                     (xaccAccountGetCommodity
-                                      (xaccSplitGetAccount s))))
-                                (and
-                                 (not (gnc-commodity-equiv
-                                       trans-comm acc-comm))
-                                 (or
-                                  (not commodity)
-                                  (gnc-commodity-equiv
-                                   commodity trans-comm)
-                                  (gnc-commodity-equiv
-                                   commodity acc-comm)))))
-                  (qof-query-run query)))
-    (qof-query-destroy query)
-    splits))
+  (filter
+   (lambda (s)
+     (let ((txn-comm (xaccTransGetCurrency (xaccSplitGetParent s)))
+           (acc-comm (xaccAccountGetCommodity (xaccSplitGetAccount s))))
+       (and (not (gnc-commodity-equiv txn-comm acc-comm))
+            (or (not commodity)
+                (gnc-commodity-equiv commodity txn-comm)
+                (gnc-commodity-equiv commodity acc-comm)))))
+   (get-all-splits currency-accounts end-date)))
 
 ;; Returns a sorted list of all splits in the 'currency-accounts' up
 ;; to 'end-date' which have the 'commodity' and one other commodity
@@ -109,7 +93,7 @@ construct with gnc:make-gnc-monetary and gnc:monetary->string instead.")
 ;; Returns true if the given pricealist element is a non-zero price.
 (define (gnc:price-is-not-zero? elem)
   (and (second elem)
-       (not (gnc-numeric-zero-p (second elem)))))
+       (not (zero? (second elem)))))
 
 ;; Create a list of all prices of 'price-commodity' measured in the currency
 ;; 'report-currency'. The prices are taken from all splits in
@@ -131,8 +115,16 @@ construct with gnc:make-gnc-monetary and gnc:monetary->string instead.")
 
 (define (gnc:get-commodity-totalavg-prices
          currency-accounts end-date price-commodity report-currency)
-  (let ((total-foreign (gnc-numeric-zero))
-        (total-domestic (gnc-numeric-zero)))
+  (gnc:get-commodity-totalavg-prices-internal
+   currency-accounts end-date price-commodity report-currency
+   (gnc:get-match-commodity-splits-sorted
+    currency-accounts end-date price-commodity)))
+
+(define (gnc:get-commodity-totalavg-prices-internal
+         currency-accounts end-date price-commodity report-currency
+         commodity-splits)
+  (let ((total-foreign 0)
+        (total-domestic 0))
     (filter
      gnc:price-is-not-zero?
      (map-in-order
@@ -141,9 +133,9 @@ construct with gnc:make-gnc-monetary and gnc:monetary->string instead.")
                                   (xaccSplitGetParent a)))
                (account-comm (xaccAccountGetCommodity
                               (xaccSplitGetAccount a)))
-               (share-amount (gnc-numeric-abs
+               (share-amount (abs
                               (xaccSplitGetAmount a)))
-               (value-amount (gnc-numeric-abs
+               (value-amount (abs
                               (xaccSplitGetValue a)))
                (transaction-date (xaccTransGetDate
                                   (xaccSplitGetParent a)))
@@ -190,8 +182,8 @@ construct with gnc:make-gnc-monetary and gnc:monetary->string instead.")
                            ") =? "
                            (gnc:monetary->string
                             (gnc:make-gnc-monetary
-                            report-currency (gnc-numeric-zero))))
-                     (gnc-numeric-zero))
+                            report-currency 0)))
+                     0)
                    (begin
                      (set! total-foreign (gnc-numeric-add total-foreign
                                                           (third foreignlist)
@@ -208,11 +200,8 @@ construct with gnc:make-gnc-monetary and gnc:monetary->string instead.")
                           GNC-DENOM-AUTO
                           (logior (GNC-DENOM-SIGFIGS 8) GNC-RND-ROUND)) 0)))
                #f))))
-      ;; Get all the interesting splits, and sort them according to the
-      ;; date.
-      (gnc:get-match-commodity-splits-sorted
-       currency-accounts
-       end-date price-commodity)))))
+      commodity-splits))))
+
 
 ;; Create a list of prices for all commodities in 'commodity-list',
 ;; i.e. the same thing as in get-commodity-totalavg-prices but
@@ -222,22 +211,32 @@ construct with gnc:make-gnc-monetary and gnc:monetary->string instead.")
 (define (gnc:get-commoditylist-totalavg-prices
          commodity-list report-currency end-date
          start-percent delta-percent)
-  (let ((currency-accounts
-         ;;(filter gnc:account-has-shares?
-         ;; -- use all accounts, not only share accounts, since gnucash-1.7
-         (gnc-account-get-descendants-sorted (gnc-get-current-root-account)))
-        (work-to-do (length commodity-list))
-        (work-done 0))
+  (define (interesting-split? s)
+    (not (gnc-commodity-equiv
+          (xaccTransGetCurrency (xaccSplitGetParent s))
+          (xaccAccountGetCommodity (xaccSplitGetAccount s)))))
+  (define (date<? a b)
+    (< (xaccTransGetDate (xaccSplitGetParent a))
+       (xaccTransGetDate (xaccSplitGetParent b))))
+  (let* ((currency-accounts
+          (gnc-account-get-descendants-sorted (gnc-get-current-root-account)))
+         (all-splits (get-all-splits currency-accounts end-date))
+         (interesting-splits (sort (filter interesting-split? all-splits) date<?))
+         (work-to-do (length commodity-list))
+         (work-done 0))
     (map
      (lambda (c)
-       (begin
-         (set! work-done (+ 1 work-done))
-         (if start-percent
-             (gnc:report-percent-done
-              (+ start-percent (* delta-percent (/ work-done work-to-do)))))
-         (cons c
-               (gnc:get-commodity-totalavg-prices
-                currency-accounts end-date c report-currency))))
+       (define (split-has-commodity? s)
+         (or (gnc-commodity-equiv c (xaccTransGetCurrency (xaccSplitGetParent s)))
+             (gnc-commodity-equiv c (xaccAccountGetCommodity (xaccSplitGetAccount s)))))
+       (set! work-done (1+ work-done))
+       (if start-percent
+           (gnc:report-percent-done
+            (+ start-percent (* delta-percent (/ work-done work-to-do)))))
+       (cons c
+             (gnc:get-commodity-totalavg-prices-internal
+              currency-accounts end-date c report-currency
+              (filter split-has-commodity? interesting-splits))))
      commodity-list)))
 
 ;; Get the instantaneous prices for the 'price-commodity', measured in
@@ -257,9 +256,9 @@ construct with gnc:make-gnc-monetary and gnc:monetary->string instead.")
                                 (xaccSplitGetParent a)))
              (account-comm (xaccAccountGetCommodity
                             (xaccSplitGetAccount a)))
-             (share-amount (gnc-numeric-abs
+             (share-amount (abs
                             (xaccSplitGetAmount a)))
-             (value-amount (gnc-numeric-abs
+             (value-amount (abs
                             (xaccSplitGetValue a)))
              (transaction-date (xaccTransGetDate
                                 (xaccSplitGetParent a)))
@@ -299,8 +298,8 @@ construct with gnc:make-gnc-monetary and gnc:monetary->string instead.")
                        ") =? "
                        (gnc:monetary->string
                         (gnc:make-gnc-monetary
-                         report-currency (gnc-numeric-zero))))
-               (gnc-numeric-zero))
+                         report-currency 0)))
+               0)
              (if (not (zero? (third foreignlist)))
                  (gnc-numeric-div
                   (second foreignlist)
@@ -321,8 +320,6 @@ construct with gnc:make-gnc-monetary and gnc:monetary->string instead.")
          commodity-list report-currency end-date
          start-percent delta-percent)
   (let ((currency-accounts
-         ;;(filter gnc:account-has-shares?
-         ;; -- use all accounts, not only share accounts, since gnucash-1.7
          (gnc-account-get-descendants-sorted (gnc-get-current-root-account)))
         (work-to-do (length commodity-list))
         (work-done 0))
@@ -375,19 +372,12 @@ construct with gnc:make-gnc-monetary and gnc:monetary->string instead.")
 
 ;; Find the price of the 'commodity' in the 'pricealist' that is
 ;; nearest to the 'date'.
-(define (gnc:pricealist-lookup-nearest-in-time
-         pricealist commodity date)
+(define (gnc:pricealist-lookup-nearest-in-time pricealist commodity date)
   (let ((plist (assoc-ref pricealist commodity)))
-    (if (and plist (not (null? plist)))
-        (let ((price
-               (gnc:pricelist-price-find-nearest
-                plist date)))
-          (or price
-              (gnc-numeric-zero)))
-        (gnc-numeric-zero))))
-
-
-
+    (or (and plist
+             (not (null? plist))
+             (gnc:pricelist-price-find-nearest plist date))
+        0)))
 
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 ;; Functions to get one price at a given time (i.e. not time-variant).
@@ -474,7 +464,7 @@ construct with gnc:make-gnc-monetary and gnc:monetary->string instead.")
                      ;; Find the pair's currency in reportlist. FIXME:
                      ;; Also try the Euro here.
                      (pair-b (assoc (car pair) reportlist))
-                     (rate (gnc-numeric-zero)))
+                     (rate 0))
                  (if (and (not pair-a) (not pair-b))
                      ;; If neither the currency of otherlist nor of
                      ;; pair was found in reportlist then we can't
@@ -488,7 +478,7 @@ construct with gnc:make-gnc-monetary and gnc:monetary->string instead.")
                             (gnc:make-gnc-monetary (car otherlist) ((cdadr pair) 'total #f)))
                            " to "
                            (gnc:monetary->string
-                            (gnc:make-gnc-monetary report-commodity (gnc-numeric-zero))))
+                            (gnc:make-gnc-monetary report-commodity 0)))
                      (if (and pair-a pair-b)
                          ;; If both currencies are found then something
                          ;; went wrong inside
@@ -541,8 +531,6 @@ construct with gnc:make-gnc-monetary and gnc:monetary->string instead.")
 
 (define (gnc:get-exchange-totals report-commodity end-date)
   (let ((curr-accounts
-         ;;(filter gnc:account-has-shares? ))
-         ;; -- use all accounts, not only share accounts, since gnucash-1.7
          (gnc-account-get-descendants-sorted (gnc-get-current-root-account)))
         (sumlist (list (list report-commodity '()))))
 
@@ -556,16 +544,14 @@ construct with gnc:make-gnc-monetary and gnc:monetary->string instead.")
                   (account-comm (xaccAccountGetCommodity
                                  (xaccSplitGetAccount a)))
                   ;; Always use the absolute value here.
-                  (share-amount (gnc-numeric-abs
+                  (share-amount (abs
                                  (xaccSplitGetAmount a)))
-                  (value-amount (gnc-numeric-abs
+                  (value-amount (abs
                                  (xaccSplitGetValue a)))
-                  (tmp (assoc transaction-comm sumlist))
-                  (comm-list (if (not tmp)
-                                 (assoc account-comm sumlist)
-                                 tmp)))
+                  (comm-list (or (assoc transaction-comm sumlist)
+                                 (assoc account-comm sumlist))))
 
-             (cond ((gnc-numeric-zero-p share-amount)
+             (cond ((zero? share-amount)
                     ;; Without shares this is not a buy or sell; ignore it.
                     #f)
 
@@ -617,11 +603,8 @@ construct with gnc:make-gnc-monetary and gnc:monetary->string instead.")
 ;; Sum the net amounts and values in the report commodity, including booked
 ;; gains and losses, of each commodity across all accounts. Returns a
 ;; report-list.
-
 (define (gnc:get-exchange-cost-totals report-commodity end-date)
   (let ((curr-accounts
-         ;;(filter gnc:account-has-shares? ))
-         ;; -- use all accounts, not only share accounts, since gnucash-1.7
          (gnc-account-get-descendants-sorted (gnc-get-current-root-account)))
         (sumlist (list (list report-commodity '()))))
 
@@ -639,10 +622,8 @@ construct with gnc:make-gnc-monetary and gnc:monetary->string instead.")
                                      (xaccSplitGetAccount a)))
                       (share-amount (xaccSplitGetAmount a))
                       (value-amount (xaccSplitGetValue a))
-                      (tmp (assoc transaction-comm sumlist))
-                      (comm-list (if (not tmp)
-                                     (assoc account-comm sumlist)
-                                     tmp)))
+                      (comm-list (or (assoc transaction-comm sumlist)
+                                     (assoc account-comm sumlist))))
 
                  ;; entry exists already in comm-list?
                  (if (not comm-list)
@@ -664,8 +645,8 @@ construct with gnc:make-gnc-monetary and gnc:monetary->string instead.")
                                (list account-comm
                                      share-amount value-amount)
                                (list transaction-comm
-                                     (gnc-numeric-neg value-amount)
-                                     (gnc-numeric-neg share-amount))))
+                                     (- value-amount)
+                                     (- share-amount))))
                           ;; second commodity already existing in comm-list?
                           (pair (assoc (car foreignlist) (cadr comm-list))))
                        ;; if not, create a new entry in comm-list.
@@ -699,7 +680,7 @@ construct with gnc:make-gnc-monetary and gnc:monetary->string instead.")
   (map
    (lambda (e)
      (list (car e)
-           (gnc-numeric-abs
+           (abs
             (gnc-numeric-div ((cdadr e) 'total #f)
                              ((caadr e) 'total #f)
                              GNC-DENOM-AUTO
@@ -714,7 +695,7 @@ construct with gnc:make-gnc-monetary and gnc:monetary->string instead.")
    (lambda (e)
      (list (car e)
            (if (zero? ((caadr e) 'total #f)) #f
-           (gnc-numeric-abs
+           (abs
             (gnc-numeric-div ((cdadr e) 'total #f)
                              ((caadr e) 'total #f)
                              GNC-DENOM-AUTO
@@ -778,8 +759,8 @@ construct with gnc:make-gnc-monetary and gnc:monetary->string instead.")
                                    exchangelist))
                       (foreign-amount (gnc:gnc-monetary-amount foreign)))
                   (if (or (not pair)
-                          (gnc-numeric-zero-p foreign-amount))
-                      (gnc-numeric-zero)
+                          (zero? foreign-amount))
+                      0
                       (gnc-numeric-mul foreign-amount
                                        (cadr pair)
                                        (gnc-commodity-get-fraction domestic)
@@ -802,8 +783,8 @@ construct with gnc:make-gnc-monetary and gnc:monetary->string instead.")
               (warn "gnc:exchange-by-pricevalue-helper: No price found for "
                     (gnc:monetary->string foreign) " into "
                     (gnc:monetary->string
-                     (gnc:make-gnc-monetary domestic (gnc-numeric-zero))))
-              (gnc-numeric-zero))))))
+                     (gnc:make-gnc-monetary domestic 0)))
+              0)))))
 
 ;; Helper for gnc:exchange-by-pricedb-* below. 'price' gets tested for
 ;; #f here, and gets unref'd here too. Exchange the <gnc:monetary>
@@ -826,8 +807,8 @@ construct with gnc:make-gnc-monetary and gnc:monetary->string instead.")
               (warn "gnc:exchange-by-pricedb-helper: No price found for "
                     (gnc:monetary->string foreign) " into "
                     (gnc:monetary->string
-                     (gnc:make-gnc-monetary domestic (gnc-numeric-zero))))
-              (gnc-numeric-zero))))))
+                     (gnc:make-gnc-monetary domestic 0)))
+              0)))))
 
 ;; This is another ready-to-use function for calculation of exchange
 ;; rates. (Note that this is already the function itself. It doesn't
