@@ -1857,7 +1857,6 @@ integer_to_words(gint64 val)
     if (val > 0)
     {
         this_part = val;
-        val -= this_part;
         g_string_append(result, gettext(small_numbers[this_part]));
         g_string_append_c(result, ' ');
     }
@@ -1985,12 +1984,21 @@ multiplier (int num_decimals)
 gboolean
 xaccParseAmount (const char * in_str, gboolean monetary, gnc_numeric *result,
                  char **endstr)
+{
+    return xaccParseAmountPosSign (in_str, monetary, result, endstr, FALSE);
+}
+
+gboolean
+xaccParseAmountPosSign (const char * in_str, gboolean monetary, gnc_numeric *result,
+                        char **endstr, gboolean skip)
 {
     struct lconv *lc = gnc_localeconv();
 
     gunichar negative_sign;
     gunichar decimal_point;
     gunichar group_separator;
+    gchar *ignore = NULL;
+    char *plus_sign = "+";
     char *group;
 
     negative_sign = g_utf8_get_char(lc->negative_sign);
@@ -2007,8 +2015,18 @@ xaccParseAmount (const char * in_str, gboolean monetary, gnc_numeric *result,
         group = lc->grouping;
     }
 
+    if (skip)
+    {
+        /* We want the locale's positive sign to be ignored.
+        * If the locale doesn't specify one, we assume "+" as
+        * an optional positive sign and ignore that */
+        ignore = lc->positive_sign;
+        if (!ignore || !*ignore)
+            ignore = plus_sign;
+    }
+
     return xaccParseAmountExtended(in_str, monetary, negative_sign, decimal_point,
-                                   group_separator, group, NULL, result, endstr);
+                                   group_separator, group, ignore, result, endstr);
 }
 
 /* Note: xaccParseAmountExtended causes test-print-parse-amount
