@@ -1243,6 +1243,15 @@ gnc_tm_get_day_start (struct tm *tm, time64 time_val)
     gnc_tm_set_day_start(tm);
 }
 
+static void
+gnc_tm_get_day_neutral (struct tm *tm, time64 time_val)
+{
+    /* Get the equivalent time structure */
+    if (!gnc_localtime_r(&time_val, tm))
+        return;
+    gnc_tm_set_day_neutral(tm);
+}
+
 static void
 gnc_tm_get_day_end (struct tm *tm, time64 time_val)
 {
@@ -1263,6 +1272,17 @@ gnc_time64_get_day_start (time64 time_val)
     return new_time;
 }
 
+time64
+gnc_time64_get_day_neutral (time64 time_val)
+{
+    struct tm tm;
+    time64 new_time;
+
+    gnc_tm_get_day_neutral(&tm, time_val);
+    new_time = gnc_mktime(&tm);
+    return new_time;
+}
+
 time64
 gnc_time64_get_day_end (time64 time_val)
 {
